@@ -452,8 +452,19 @@ void TeleWindow::layoutThumbnails()
     int tileWidth = _width / columns;
     int tileHeight = _height / rows;
 
-    int thumbWidth = maxSize;
-    int thumbHeight= maxSize * _height / _width;
+    int thumbWidth, thumbHeight;
+
+    if (n > 1)
+    {
+        thumbWidth = maxSize;
+        thumbHeight= maxSize * _height / _width;
+    }
+    else
+    {
+        // If there is only one window we don't want it become to big
+        thumbWidth = 800 * 2 / 3;
+        thumbHeight = 480 * 2 / 3;
+    }
 
     int widthWithBorder = thumbWidth + 2*_borderWidth;
     int heightWithBorder= thumbHeight+ _borderWidth + _headerHeight;
